# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v2/get_daily.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import filter_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_filter__pb2
from systemathics.apis.type.shared.v1 import option_type_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_option__type__pb2
from systemathics.apis.type.shared.v1 import strike_type_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_strike__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3systemathics/apis/services/daily/v2/get_daily.proto\x12#systemathics.apis.services.daily.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x16google/type/date.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a-systemathics/apis/type/shared/v1/filter.proto\x1a\x32systemathics/apis/type/shared/v1/option_type.proto\x1a\x32systemathics/apis/type/shared/v1/strike_type.proto\"\xc5\x01\n\x0c\x44\x61ilyRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\xe0\x01\n\x15\x44\x61ilyVectorKeyRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12O\n\x0b\x63onstraints\x18\x04 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\xc6\x01\n\x19\x44\x61ilyScalarStreamResponse\x12L\n\x04info\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.daily.v2.DailyStreamFieldsH\x00R\x04info\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.systemathics.apis.services.daily.v2.DailyScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"\xc6\x01\n\x19\x44\x61ilyVectorStreamResponse\x12L\n\x04info\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.daily.v2.DailyStreamFieldsH\x00R\x04info\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.systemathics.apis.services.daily.v2.DailyVectorStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"y\n\x11\x44\x61ilyStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\x12L\n\nidentifier\x18\x02 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\"R\n\x15\x44\x61ilyScalarStreamItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"d\n\x15\x44\x61ilyVectorStreamItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta\"y\n\x1b\x44\x61ilyAssetProvidersResponse\x12Z\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.daily.v2.DailyAssetProviderItemReponseR\x06\x61ssets\"\x89\x01\n\x1d\x44\x61ilyAssetProviderItemReponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1c\n\tproviders\x18\x02 \x03(\tR\tproviders\"\xc5\x01\n\x13\x44\x61ilyFieldsResponse\x12V\n\x07scalars\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.daily.v2.DailyFieldsItemResponseR\x07scalars\x12V\n\x07vectors\x18\x02 \x03(\x0b\x32<.systemathics.apis.services.daily.v2.DailyFieldsItemResponseR\x07vectors\"\x99\x01\n\x17\x44\x61ilyFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\"\xe7\x04\n)DailyOptionUnderlierWithStrikeTypeRequest\x12R\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierB\x04\xe2\x41\x01\x02R\nidentifier\x12Y\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalB\x04\xe2\x41\x01\x02R\x0c\x64\x61teInterval\x12W\n\rmaturity_date\x18\x03 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.DateFilterB\x04\xe2\x41\x01\x01R\x0cmaturityDate\x12]\n\x0fstrike_interval\x18\x04 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DoubleFilterB\x04\xe2\x41\x01\x01R\x0estrikeInterval\x12S\n\x0boption_type\x18\x05 \x01(\x0e\x32,.systemathics.apis.type.shared.v1.OptionTypeB\x04\xe2\x41\x01\x01R\noptionType\x12S\n\x0bstrike_type\x18\x06 \x01(\x0e\x32,.systemathics.apis.type.shared.v1.StrikeTypeB\x04\xe2\x41\x01\x01R\nstrikeType\x12)\n\rdouble_fields\x18\x07 \x03(\tB\x04\xe2\x41\x01\x02R\x0c\x64oubleFields\"\x85\x02\n(DailyUnderlierOptionWithStrikeTypeStream\x12R\n\x04info\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.daily.v2.DailyStreamFieldsB\x04\xe2\x41\x01\x01H\x00R\x04info\x12z\n\x0b\x64ouble_data\x18\x02 \x01(\x0b\x32Q.systemathics.apis.services.daily.v2.DailyUnderlierOptionWithStrikeTypeStreamItemB\x04\xe2\x41\x01\x01H\x00R\ndoubleDataB\t\n\x07payload\"\xfb\x02\n,DailyUnderlierOptionWithStrikeTypeStreamItem\x12+\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x02R\x04\x64\x61te\x12<\n\rmaturity_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x02R\x0cmaturityDate\x12\x1c\n\x06strike\x18\x03 \x01(\x01\x42\x04\xe2\x41\x01\x02R\x06strike\x12S\n\x0boption_type\x18\x04 \x01(\x0e\x32,.systemathics.apis.type.shared.v1.OptionTypeB\x04\xe2\x41\x01\x02R\noptionType\x12S\n\x0bstrike_type\x18\x05 \x01(\x0e\x32,.systemathics.apis.type.shared.v1.StrikeTypeB\x04\xe2\x41\x01\x02R\nstrikeType\x12\x18\n\x04\x64\x61ta\x18\x06 \x03(\x01\x42\x04\xe2\x41\x01\x01R\x04\x64\x61ta2\x9f\x08\n\x0c\x44\x61ilyService\x12\xa3\x01\n\x11\x44\x61ilyScalarStream\x12\x31.systemathics.apis.services.daily.v2.DailyRequest\x1a>.systemathics.apis.services.daily.v2.DailyScalarStreamResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_scalar/0\x01\x12\xa3\x01\n\x11\x44\x61ilyVectorStream\x12\x31.systemathics.apis.services.daily.v2.DailyRequest\x1a>.systemathics.apis.services.daily.v2.DailyVectorStreamResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_vector/0\x01\x12\xb3\x01\n\x14\x44\x61ilyVectorKeyStream\x12:.systemathics.apis.services.daily.v2.DailyVectorKeyRequest\x1a>.systemathics.apis.services.daily.v2.DailyVectorStreamResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v2/daily_vector_key/0\x01\x12\x81\x02\n(DailyOptionUnderlierWithStrikeTypeStream\x12N.systemathics.apis.services.daily.v2.DailyOptionUnderlierWithStrikeTypeRequest\x1aM.systemathics.apis.services.daily.v2.DailyUnderlierOptionWithStrikeTypeStream\"4\x82\xd3\xe4\x93\x02.\x12,/v2/daily_option_underlier_with_strike_type/0\x01\x12z\n\x0b\x44\x61ilyFields\x12\x16.google.protobuf.Empty\x1a\x38.systemathics.apis.services.daily.v2.DailyFieldsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_fields/\x12\x8c\x01\n\x13\x44\x61ilyAssetProviders\x12\x16.google.protobuf.Empty\x1a@.systemathics.apis.services.daily.v2.DailyAssetProvidersResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v2/daily_provider/B\xe9\x01\n\'com.systemathics.apis.services.daily.v2B\rGetDailyProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V2\xca\x02#Systemathics\\Apis\\Services\\Daily\\V2\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v2.get_daily_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v2B\rGetDailyProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V2\312\002#Systemathics\\Apis\\Services\\Daily\\V2\342\002/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V2'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['identifier']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['identifier']._serialized_options = b'\342A\001\002'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['date_interval']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['date_interval']._serialized_options = b'\342A\001\002'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['maturity_date']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['maturity_date']._serialized_options = b'\342A\001\001'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['strike_interval']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['strike_interval']._serialized_options = b'\342A\001\001'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['option_type']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['option_type']._serialized_options = b'\342A\001\001'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['strike_type']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['strike_type']._serialized_options = b'\342A\001\001'
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['double_fields']._options = None
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST'].fields_by_name['double_fields']._serialized_options = b'\342A\001\002'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAM'].fields_by_name['info']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAM'].fields_by_name['info']._serialized_options = b'\342A\001\001'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAM'].fields_by_name['double_data']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAM'].fields_by_name['double_data']._serialized_options = b'\342A\001\001'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['date']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['date']._serialized_options = b'\342A\001\002'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['maturity_date']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['maturity_date']._serialized_options = b'\342A\001\002'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['strike']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['strike']._serialized_options = b'\342A\001\002'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['option_type']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['option_type']._serialized_options = b'\342A\001\002'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['strike_type']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['strike_type']._serialized_options = b'\342A\001\002'
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['data']._options = None
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM'].fields_by_name['data']._serialized_options = b'\342A\001\001'
  _globals['_DAILYSERVICE'].methods_by_name['DailyScalarStream']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyScalarStream']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_scalar/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyVectorStream']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyVectorStream']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_vector/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyVectorKeyStream']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyVectorKeyStream']._serialized_options = b'\202\323\344\223\002\027\022\025/v2/daily_vector_key/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyOptionUnderlierWithStrikeTypeStream']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyOptionUnderlierWithStrikeTypeStream']._serialized_options = b'\202\323\344\223\002.\022,/v2/daily_option_underlier_with_strike_type/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyFields']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyFields']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_fields/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyAssetProviders']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyAssetProviders']._serialized_options = b'\202\323\344\223\002\025\022\023/v2/daily_provider/'
  _globals['_DAILYREQUEST']._serialized_start=563
  _globals['_DAILYREQUEST']._serialized_end=760
  _globals['_DAILYVECTORKEYREQUEST']._serialized_start=763
  _globals['_DAILYVECTORKEYREQUEST']._serialized_end=987
  _globals['_DAILYSCALARSTREAMRESPONSE']._serialized_start=990
  _globals['_DAILYSCALARSTREAMRESPONSE']._serialized_end=1188
  _globals['_DAILYVECTORSTREAMRESPONSE']._serialized_start=1191
  _globals['_DAILYVECTORSTREAMRESPONSE']._serialized_end=1389
  _globals['_DAILYSTREAMFIELDS']._serialized_start=1391
  _globals['_DAILYSTREAMFIELDS']._serialized_end=1512
  _globals['_DAILYSCALARSTREAMITEM']._serialized_start=1514
  _globals['_DAILYSCALARSTREAMITEM']._serialized_end=1596
  _globals['_DAILYVECTORSTREAMITEM']._serialized_start=1598
  _globals['_DAILYVECTORSTREAMITEM']._serialized_end=1698
  _globals['_DAILYASSETPROVIDERSRESPONSE']._serialized_start=1700
  _globals['_DAILYASSETPROVIDERSRESPONSE']._serialized_end=1821
  _globals['_DAILYASSETPROVIDERITEMREPONSE']._serialized_start=1824
  _globals['_DAILYASSETPROVIDERITEMREPONSE']._serialized_end=1961
  _globals['_DAILYFIELDSRESPONSE']._serialized_start=1964
  _globals['_DAILYFIELDSRESPONSE']._serialized_end=2161
  _globals['_DAILYFIELDSITEMRESPONSE']._serialized_start=2164
  _globals['_DAILYFIELDSITEMRESPONSE']._serialized_end=2317
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST']._serialized_start=2320
  _globals['_DAILYOPTIONUNDERLIERWITHSTRIKETYPEREQUEST']._serialized_end=2935
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAM']._serialized_start=2938
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAM']._serialized_end=3199
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM']._serialized_start=3202
  _globals['_DAILYUNDERLIEROPTIONWITHSTRIKETYPESTREAMITEM']._serialized_end=3581
  _globals['_DAILYSERVICE']._serialized_start=3584
  _globals['_DAILYSERVICE']._serialized_end=4639
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/asset.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/asset.proto\x12 systemathics.apis.type.shared.v1\"^\n\x10\x41ssetTypeRequest\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType*\xc6\x02\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x12\x14\n\x10\x41SSET_TYPE_FOREX\x10\x07\x12\x15\n\x11\x41SSET_TYPE_OPTION\x10\x08\x12\x13\n\x0f\x41SSET_TYPE_BOND\x10\t\x12\x12\n\x0e\x41SSET_TYPE_CDS\x10\n\x12\x18\n\x14\x41SSET_TYPE_CDS_INDEX\x10\x0b\x12 \n\x1c\x41SSET_TYPE_CDS_INDEX_TRANCHE\x10\x0c\x12\x1f\n\x1b\x41SSET_TYPE_CDS_INDEX_OPTION\x10\rB\xd7\x01\n$com.systemathics.apis.type.shared.v1B\nAssetProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.asset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\nAssetProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_ASSETTYPE']._serialized_start=179
  _globals['_ASSETTYPE']._serialized_end=505
  _globals['_ASSETTYPEREQUEST']._serialized_start=82
  _globals['_ASSETTYPEREQUEST']._serialized_end=176
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v2/set_daily_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/services/daily/v2/set_daily_scalar.proto\x12#systemathics.apis.services.daily.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xc0\x01\n\x15SetDailyScalarRequest\x12M\n\x04info\x18\x01 \x01(\x0b\x32\x37.systemathics.apis.services.daily.v2.SetDailyScalarInfoH\x00R\x04info\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.systemathics.apis.services.daily.v2.SetDailyScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\x7f\n\x17\x43learDailyScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"\xbd\x01\n\x12SetDailyScalarInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x41\n\x04mode\x18\x03 \x01(\x0e\x32-.systemathics.apis.type.shared.v2.SetDataModeR\x04mode\"O\n\x12SetDailyScalarData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta2\x8f\x02\n\x15SetDailyScalarService\x12y\n\x0eSetDailyScalar\x12:.systemathics.apis.services.daily.v2.SetDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x11\x82\xd3\xe4\x93\x02\x0b\"\t/v2/daily(\x01\x12{\n\x10\x43learDailyScalar\x12<.systemathics.apis.services.daily.v2.ClearDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x11\x82\xd3\xe4\x93\x02\x0b*\t/v2/dailyB\xef\x01\n\'com.systemathics.apis.services.daily.v2B\x13SetDailyScalarProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V2\xca\x02#Systemathics\\Apis\\Services\\Daily\\V2\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v2.set_daily_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v2B\023SetDailyScalarProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V2\312\002#Systemathics\\Apis\\Services\\Daily\\V2\342\002/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V2'
  _globals['_SETDAILYSCALARSERVICE'].methods_by_name['SetDailyScalar']._options = None
  _globals['_SETDAILYSCALARSERVICE'].methods_by_name['SetDailyScalar']._serialized_options = b'\202\323\344\223\002\013\"\t/v2/daily'
  _globals['_SETDAILYSCALARSERVICE'].methods_by_name['ClearDailyScalar']._options = None
  _globals['_SETDAILYSCALARSERVICE'].methods_by_name['ClearDailyScalar']._serialized_options = b'\202\323\344\223\002\013*\t/v2/daily'
  _globals['_SETDAILYSCALARREQUEST']._serialized_start=418
  _globals['_SETDAILYSCALARREQUEST']._serialized_end=610
  _globals['_CLEARDAILYSCALARREQUEST']._serialized_start=612
  _globals['_CLEARDAILYSCALARREQUEST']._serialized_end=739
  _globals['_SETDAILYSCALARINFO']._serialized_start=742
  _globals['_SETDAILYSCALARINFO']._serialized_end=931
  _globals['_SETDAILYSCALARDATA']._serialized_start=933
  _globals['_SETDAILYSCALARDATA']._serialized_end=1012
  _globals['_SETDAILYSCALARSERVICE']._serialized_start=1015
  _globals['_SETDAILYSCALARSERVICE']._serialized_end=1286
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_greeks.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import time_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/intraday/v1/intraday_greeks.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a\x34systemathics/apis/type/shared/v1/time_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xd7\x02\n\x15IntradayGreeksRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12S\n\rtime_interval\x18\x04 \x01(\x0b\x32..systemathics.apis.type.shared.v1.TimeIntervalR\x0ctimeInterval\"d\n\x16IntradayGreeksResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.intraday.v1.IntradayGreeksR\x04\x64\x61ta\"\xc9\x01\n\x0eIntradayGreeks\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05\x64\x65lta\x18\x02 \x01(\x01R\x05\x64\x65lta\x12\x14\n\x05gamma\x18\x03 \x01(\x01R\x05gamma\x12\x14\n\x05theta\x18\x04 \x01(\x01R\x05theta\x12\x12\n\x04vega\x18\x05 \x01(\x01R\x04vega\x12\x10\n\x03rho\x18\x06 \x01(\x01R\x03rho\x12\x14\n\x05score\x18\x07 \x01(\x01R\x05score2\xc6\x01\n\x15IntradayGreeksService\x12\xac\x01\n\x0eIntradayGreeks\x12=.systemathics.apis.services.intraday.v1.IntradayGreeksRequest\x1a>.systemathics.apis.services.intraday.v1.IntradayGreeksResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/intraday/greeksB\xfe\x01\n*com.systemathics.apis.services.intraday.v1B\x13IntradayGreeksProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V1\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V1\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v1.intraday_greeks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v1B\023IntradayGreeksProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V1\312\002&Systemathics\\Apis\\Services\\Intraday\\V1\342\0022Systemathics\\Apis\\Services\\Intraday\\V1\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V1'
  _globals['_INTRADAYGREEKSSERVICE'].methods_by_name['IntradayGreeks']._options = None
  _globals['_INTRADAYGREEKSSERVICE'].methods_by_name['IntradayGreeks']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/intraday/greeks'
  _globals['_INTRADAYGREEKSREQUEST']._serialized_start=376
  _globals['_INTRADAYGREEKSREQUEST']._serialized_end=719
  _globals['_INTRADAYGREEKSRESPONSE']._serialized_start=721
  _globals['_INTRADAYGREEKSRESPONSE']._serialized_end=821
  _globals['_INTRADAYGREEKS']._serialized_start=824
  _globals['_INTRADAYGREEKS']._serialized_end=1025
  _globals['_INTRADAYGREEKSSERVICE']._serialized_start=1028
  _globals['_INTRADAYGREEKSSERVICE']._serialized_end=1226
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/screener_data/v1/screener_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.services.static_data.v1 import static_data_pb2 as systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2
from systemathics.apis.type.shared.v1 import option_type_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_option__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/screener_data/v1/screener_data.proto\x12+systemathics.apis.services.screener_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a;systemathics/apis/services/static_data/v1/static_data.proto\x1a\x32systemathics/apis/type/shared/v1/option_type.proto\"\x8a\x07\n\x0fScreenerRequest\x12\x31\n\x05start\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\x12\x38\n\x08\x63urrency\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63urrency\x12\x38\n\x08\x65xchange\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x65xchange\x12h\n\x0e\x63\x61pitalization\x18\x05 \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeR\x0e\x63\x61pitalization\x12V\n\x06\x65xpiry\x18\x06 \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeR\x06\x65xpiry\x12M\n\x0boption_type\x18\x07 \x01(\x0e\x32,.systemathics.apis.type.shared.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18\x08 \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\x12V\n\x05\x64\x65lta\x18\t \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeR\x05\x64\x65lta\x12o\n\x12implied_volatility\x18\n \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeR\x11impliedVolatility\x12\x65\n\ropen_interest\x18\x0b \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeR\x0copenInterest\"e\n\x10ScreenerResponse\x12Q\n\x06\x65quity\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.EquityResponseR\x06\x65quity2\xb5\x01\n\x0fScreenerService\x12\xa1\x01\n\x08Screener\x12<.systemathics.apis.services.screener_data.v1.ScreenerRequest\x1a=.systemathics.apis.services.screener_data.v1.ScreenerResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/screenerdataB\x91\x02\n/com.systemathics.apis.services.screener_data.v1B\x11ScreenerDataProtoP\x01\xa2\x02\x04SASS\xaa\x02*Systemathics.Apis.Services.ScreenerData.V1\xca\x02*Systemathics\\Apis\\Services\\ScreenerData\\V1\xe2\x02\x36Systemathics\\Apis\\Services\\ScreenerData\\V1\\GPBMetadata\xea\x02.Systemathics::Apis::Services::ScreenerData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.screener_data.v1.screener_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n/com.systemathics.apis.services.screener_data.v1B\021ScreenerDataProtoP\001\242\002\004SASS\252\002*Systemathics.Apis.Services.ScreenerData.V1\312\002*Systemathics\\Apis\\Services\\ScreenerData\\V1\342\0026Systemathics\\Apis\\Services\\ScreenerData\\V1\\GPBMetadata\352\002.Systemathics::Apis::Services::ScreenerData::V1'
  _globals['_SCREENERSERVICE'].methods_by_name['Screener']._options = None
  _globals['_SCREENERSERVICE'].methods_by_name['Screener']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/screenerdata'
  _globals['_SCREENERREQUEST']._serialized_start=288
  _globals['_SCREENERREQUEST']._serialized_end=1194
  _globals['_SCREENERRESPONSE']._serialized_start=1196
  _globals['_SCREENERRESPONSE']._serialized_end=1297
  _globals['_SCREENERSERVICE']._serialized_start=1300
  _globals['_SCREENERSERVICE']._serialized_end=1481
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.tick.v2 import get_tick_scalar_pb2 as systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2


class TickScalarServiceStub(object):
    """Called to request tick prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TickScalarStream = channel.unary_stream(
                '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarStreamResponse.FromString,
                )
        self.TickScalarFields = channel.unary_unary(
                '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarFieldsResponse.FromString,
                )
        self.TickScalarAssetProvider = channel.unary_unary(
                '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarAssetProvider',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarAssetProviderResponse.FromString,
                )


class TickScalarServiceServicer(object):
    """Called to request tick prices data. 
    """

    def TickScalarStream(self, request, context):
        """Gets tick historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickScalarFields(self, request, context):
        """Gets tick historical data by date
        rpc TickByDate(TickDateRequest) returns (stream GetTickByDateResponse)
        {
        option (google.api.http) = {
        		get: "/v2/tick_date/"
        };
        }

        Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickScalarAssetProvider(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TickScalarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TickScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.TickScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarStreamResponse.SerializeToString,
            ),
            'TickScalarFields': grpc.unary_unary_rpc_method_handler(
                    servicer.TickScalarFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarFieldsResponse.SerializeToString,
            ),
            'TickScalarAssetProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.TickScalarAssetProvider,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarAssetProviderResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.tick.v2.TickScalarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TickScalarService(object):
    """Called to request tick prices data. 
    """

    @staticmethod
    def TickScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarStream',
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickScalarFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickScalarAssetProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.tick.v2.TickScalarService/TickScalarAssetProvider',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__scalar__pb2.TickScalarAssetProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_priips.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/tick_analytics/v1/tick_priips.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1agoogle/type/datetime.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x9b\x04\n\x11TickPriipsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x34\n\norder_time\x18\x02 \x01(\x0b\x32\x15.google.type.DateTimeR\torderTime\x12<\n\x0e\x65xecution_time\x18\x03 \x01(\x0b\x32\x15.google.type.DateTimeR\rexecutionTime\x12\'\n\x0f\x65xecution_price\x18\x04 \x01(\x01R\x0e\x65xecutionPrice\x12O\n\x05\x66ield\x18\x05 \x01(\x0e\x32\x39.systemathics.apis.services.tick_analytics.v1.PriipsPriceR\x05\x66ield\x12\x33\n\x07latency\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07latency\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x07 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x08 \x03(\tR\x06reject\x12\x18\n\x07metrics\x18\t \x01(\x08R\x07metrics\x12K\n\"use_reverse_iteration_optimization\x18\n \x01(\x08R\x1fuseReverseIterationOptimization\"\xce\x0e\n\x12TickPriipsResponse\x12=\n\x0c\x61rrival_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x61rrivalTime\x12\x41\n\rarrival_price\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0c\x61rrivalPrice\x12?\n\x0c\x61rrival_cost\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0b\x61rrivalCost\x12\x37\n\topen_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08openTime\x12\x39\n\nclose_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcloseTime\x12\x39\n\norder_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\torderTime\x12\x41\n\x0e\x65xecution_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rexecutionTime\x12\x33\n\x07latency\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07latency\x12\'\n\x0f\x65xecution_price\x18\t \x01(\x01R\x0e\x65xecutionPrice\x12\x31\n\x05\x63ount\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x05\x63ount\x12;\n\nopen_price\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\topenPrice\x12;\n\nhigh_price\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\thighPrice\x12\x39\n\tlow_price\x18\r \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08lowPrice\x12=\n\x0b\x63lose_price\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\nclosePrice\x12\x30\n\x04vwap\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x04vwap\x12\x33\n\x06volume\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12\x18\n\x07message\x18\x11 \x01(\tR\x07message\x12@\n\x0e\x61rrival_period\x18\x12 \x01(\x0b\x32\x19.google.protobuf.DurationR\rarrivalPeriod\x12@\n\x0eworking_period\x18\x13 \x01(\x0b\x32\x19.google.protobuf.DurationR\rworkingPeriod\x12@\n\x0e\x63losing_period\x18\x14 \x01(\x0b\x32\x19.google.protobuf.DurationR\rclosingPeriod\x12@\n\x0eopening_period\x18\x15 \x01(\x0b\x32\x19.google.protobuf.DurationR\ropeningPeriod\x12\x39\n\ncross_time\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcrossTime\x12>\n\x0cupper_volume\x18\x17 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0bupperVolume\x12>\n\x0clower_volume\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0blowerVolume\x12>\n\x0c\x65qual_volume\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0b\x65qualVolume\x12<\n\x0bupper_count\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nupperCount\x12<\n\x0blower_count\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nlowerCount\x12<\n\x0b\x65qual_count\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nequalCount\x12\x1e\n\nconditions\x18\x1d \x03(\tR\nconditions\x12)\n\x10upper_conditions\x18\x1e \x03(\tR\x0fupperConditions\x12)\n\x10lower_conditions\x18\x1f \x03(\tR\x0flowerConditions\x12)\n\x10\x65qual_conditions\x18  \x03(\tR\x0f\x65qualConditions\x12\x1f\n\x0bticks_count\x18! \x01(\x03R\nticksCount*o\n\x0bPriipsPrice\x12\x1c\n\x18PRIIPS_PRICE_UNSPECIFIED\x10\x00\x12\x16\n\x12PRIIPS_PRICE_TRADE\x10\x01\x12\x14\n\x10PRIIPS_PRICE_BID\x10\x02\x12\x14\n\x10PRIIPS_PRICE_ASK\x10\x03\x32\xc8\x01\n\x11TickPriipsService\x12\xb2\x01\n\nTickPriips\x12?.systemathics.apis.services.tick_analytics.v1.TickPriipsRequest\x1a@.systemathics.apis.services.tick_analytics.v1.TickPriipsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/tick-analytics/priipsB\x94\x02\n0com.systemathics.apis.services.tick_analytics.v1B\x0fTickPriipsProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_priips_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\017TickPriipsProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKPRIIPSSERVICE'].methods_by_name['TickPriips']._options = None
  _globals['_TICKPRIIPSSERVICE'].methods_by_name['TickPriips']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/tick-analytics/priips'
  _globals['_PRIIPSPRICE']._serialized_start=2733
  _globals['_PRIIPSPRICE']._serialized_end=2844
  _globals['_TICKPRIIPSREQUEST']._serialized_start=319
  _globals['_TICKPRIIPSREQUEST']._serialized_end=858
  _globals['_TICKPRIIPSRESPONSE']._serialized_start=861
  _globals['_TICKPRIIPSRESPONSE']._serialized_end=2731
  _globals['_TICKPRIIPSSERVICE']._serialized_start=2847
  _globals['_TICKPRIIPSSERVICE']._serialized_end=3047
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/cache.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5systemathics/apis/services/static_data/v1/cache.proto\x12-systemathics.apis.services.set_static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a,systemathics/apis/type/shared/v1/asset.proto2\x8f\x01\n\x16\x43\x61\x63heStaticDataService\x12u\n\x08SetCache\x12\x32.systemathics.apis.type.shared.v1.AssetTypeRequest\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/staticdata/cache/B\x90\x02\n1com.systemathics.apis.services.set_static_data.v1B\nCacheProtoP\x01\xa2\x02\x04SASS\xaa\x02+Systemathics.Apis.Services.SetStaticData.V1\xca\x02+Systemathics\\Apis\\Services\\SetStaticData\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\SetStaticData\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::SetStaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.set_static_data.v1B\nCacheProtoP\001\242\002\004SASS\252\002+Systemathics.Apis.Services.SetStaticData.V1\312\002+Systemathics\\Apis\\Services\\SetStaticData\\V1\342\0027Systemathics\\Apis\\Services\\SetStaticData\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::SetStaticData::V1'
  _globals['_CACHESTATICDATASERVICE'].methods_by_name['SetCache']._options = None
  _globals['_CACHESTATICDATASERVICE'].methods_by_name['SetCache']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/staticdata/cache/'
  _globals['_CACHESTATICDATASERVICE']._serialized_start=210
  _globals['_CACHESTATICDATASERVICE']._serialized_end=353
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.daily.v2 import set_daily_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2


class SetDailyServiceStub(object):
    """Called to set daily prices data and clear. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WriteDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WriteDailyScalarStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WriteDailyVector = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVector',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WriteDailyVectorStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyScalarStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyVector = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVector',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateDailyVectorStream = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDailyVector = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyVector',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyVectorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class SetDailyServiceServicer(object):
    """Called to set daily prices data and clear. 
    """

    def WriteDailyScalar(self, request, context):
        """Sets daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteDailyScalarStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteDailyVector(self, request, context):
        """Sets daily vector timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteDailyVectorStream(self, request_iterator, context):
        """Sets daily vector timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyScalar(self, request, context):
        """Update daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyScalarStream(self, request_iterator, context):
        """Update daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyVector(self, request, context):
        """Update daily vectors timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDailyVectorStream(self, request_iterator, context):
        """Update daily vectors timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDailyScalar(self, request, context):
        """Delete daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDailyVector(self, request, context):
        """Delete daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SetDailyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WriteDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WriteDailyScalarStream': grpc.stream_unary_rpc_method_handler(
                    servicer.WriteDailyScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WriteDailyVector': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteDailyVector,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WriteDailyVectorStream': grpc.stream_unary_rpc_method_handler(
                    servicer.WriteDailyVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyScalarStream': grpc.stream_unary_rpc_method_handler(
                    servicer.UpdateDailyScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyVector': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDailyVector,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateDailyVectorStream': grpc.stream_unary_rpc_method_handler(
                    servicer.UpdateDailyVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDailyVector': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDailyVector,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyVectorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v2.SetDailyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SetDailyService(object):
    """Called to set daily prices data and clear. 
    """

    @staticmethod
    def WriteDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteDailyScalarStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyScalarStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteDailyVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVector',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteDailyVectorStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/WriteDailyVectorStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyScalarStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyScalarStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyScalarStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVector',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDailyVectorStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyService/UpdateDailyVectorStream',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.SetDailyVectorStreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDailyVector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyService/DeleteDailyVector',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__pb2.DeleteDailyVectorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
